@@ -1,5 +1,6 @@
+from symbl.utils.Logger import Log
 from symbl.Conversations import Conversation
-from symbl.AuthenticationToken import get_api_client
+from symbl import AuthenticationToken
 from symbl_rest import AsyncApi as async_api_rest
 
 
@@ -11,7 +12,7 @@ def initialize_api_client(function):
         if 'credentials' in kw:
             credentials = kw['credentials']
 
-        api_client = get_api_client(credentials)
+        api_client = AuthenticationToken.get_api_client(credentials)
         self.__async_api_rest = async_api_rest(api_client)
 
         return function(*args, **kw)
@@ -47,7 +48,7 @@ class Audio():
         file = open(file_path, 'rb')
         audio_file = file.read()
         response = self.__async_api_rest.add_audio(body=audio_file, content_type=content_type, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
 
@@ -62,7 +63,7 @@ class Audio():
             raise ValueError("Please enter a valid file_path")
 
         response = self.__async_api_rest.add_audio_url(body={ 'url': url }, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
         
@@ -82,7 +83,7 @@ class Audio():
         file = open(file_path, 'rb')
         audio_file = file.read()
         response = self.__async_api_rest.append_audio(body=audio_file, content_type=content_type, conversation_id=conversation_id,  **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
   
@@ -99,6 +100,6 @@ class Audio():
             raise ValueError("Please enter a valid conversationId")
 
         response = self.__async_api_rest.append_audio_url(body={ 'url': url }, conversation_id=conversation_id,  **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
