@@ -1,5 +1,6 @@
+from symbl.utils.Logger import Log
 from symbl.Conversations import Conversation
-from symbl.AuthenticationToken import get_api_client
+from symbl import AuthenticationToken
 from symbl_rest import AsyncApi as async_api_rest
 
 def initialize_api_client(function):
@@ -10,7 +11,7 @@ def initialize_api_client(function):
         if 'credentials' in kw:
             credentials = kw['credentials']
 
-        api_client = get_api_client(credentials)
+        api_client = AuthenticationToken.get_api_client(credentials)
         self.__async_api_rest = async_api_rest(api_client)
 
         return function(*args, **kw)
@@ -45,7 +46,7 @@ class Text():
             raise ValueError("Please enter a valid payload.")
 
         response = self.__async_api_rest.add_text(body=payload, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
 
@@ -62,6 +63,6 @@ class Text():
             raise ValueError("Please enter a valid conversationId")
 
         response = self.__async_api_rest.append_text(conversation_id, body=payload, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
\ No newline at end of file
