@@ -1,6 +1,7 @@
 from symbl.Conversations import Conversation
-from symbl.AuthenticationToken import get_api_client
+from symbl import AuthenticationToken
 from symbl_rest import AsyncApi as async_api_rest
+from symbl.utils.Logger import Log
 
 def initialize_api_client(function):
     def wrapper(*args, **kw):
@@ -10,7 +11,7 @@ def initialize_api_client(function):
         if 'credentials' in kw:
             credentials = kw['credentials']
 
-        api_client = get_api_client(credentials)
+        api_client = AuthenticationToken.get_api_client(credentials)
         self.async_api_rest = async_api_rest(api_client)
 
         return function(*args, **kw)
@@ -46,7 +47,7 @@ class Video():
         file = open(file_path, 'rb')
         video_file = file.read()
         response = self.__async_api_rest.add_video(body=video_file, content_type=content_type, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
 
@@ -62,7 +63,7 @@ class Video():
             raise ValueError("Please enter a valid url.")
 
         response = self.__async_api_rest.add_video_url(body={ 'url': url }, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
 
@@ -82,7 +83,7 @@ class Video():
         file = open(file_path, 'rb')
         video_file = file.read()
         response = self.__async_api_rest.append_video(body=video_file, content_type=content_type, conversation_id=conversation_id, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
 
@@ -100,6 +101,6 @@ class Video():
             raise ValueError("Please enter a valid conversation_id")
 
         response = self.__async_api_rest.append_video_url(body={ 'url': url }, conversation_id=conversation_id, **correct_boolean_values(parameters))
-        print("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
+        Log.getInstance().info("Job with jobId {} for conversationId {} started".format(response.job_id, response.conversation_id))
 
         return Conversation(response.conversation_id, response.job_id, wait=wait, credentials=credentials)
\ No newline at end of file
